@@ -32,18 +32,18 @@ log = getLogger("service")
 
 
 class NDUCameraService(Thread):
-    def __init__(self, instance=None, config_dir="", handler=None, is_main_thread=True, extension_folder=None):
+    def __init__(self, instance=None, config_dir="", handler=None, is_main_thread=True, extension_folder=None, config_file="", timestamp=""):
         self.__is_main_thread = is_main_thread
         if instance is None:
             instance = {}
         super().__init__()
         self.__result_handler = handler
         self._ndu_gate_config_dir = config_dir
+        self._ndu_config_file = config_file
         self.__extension_folder = extension_folder
         self.RUNNERS = instance.get("runners", [])
         self.SOURCE_TYPE = VideoSourceType.CAMERA
         self.SOURCE_CONFIG = None
-
         if instance.get("source"):
             self.SOURCE_CONFIG = instance.get("source")
             type_str = self.SOURCE_CONFIG.get("type", "PI_CAMERA")
@@ -110,6 +110,7 @@ class NDUCameraService(Thread):
 
         self.video_source = None
         self._steps = {}
+        self.timestamp = timestamp
         # self._start()
 
     # def run(self):
@@ -391,11 +392,19 @@ class NDUCameraService(Thread):
             has_motion_kernel = self.__motion_kernel is not None
             results_for_preview = None
             for _frame_index, frame in self.video_source.get_frames():
+                if self.__result_handler.get_restart_required():
+                    self._exit_requested = True
+                    try:
+                        cv2.destroyWindow(self._winname)
+                    except:
+                        pass
+
                 if self._exit_requested:
                     break
                 i += 1
                 if i > self.__camera_refresh_interval:
                     break
+
                 if self.__skip_frame > 1 and i % self.__skip_frame != 0:
                     continue
                 if has_motion_kernel:
@@ -418,13 +427,17 @@ class NDUCameraService(Thread):
                     log.debug("frame count %s ", i)
                     print("Source Device : {} - frame {}".format(device, i))
 
+                camera_capture_base64 = image_helper.frame2base64(frame)
+                self.__result_handler.set_frame(device, camera_capture_base64)
                 if i % self.__frame_send_interval == 0:
                     try:
                         camera_capture_base64 = image_helper.frame2base64(frame)
                         log.info("CAMERA_CAPTURE size : %s", len(camera_capture_base64))
                         print("CAMERA_CAPTURE size : {}".format(len(camera_capture_base64)))
+                        #print(camera_capture_base64)
+
                         if self.frame_sent:
-                            if len(camera_capture_base64) < 16000:
+                            if len(camera_capture_base64) < 45000:
                                 self.__result_handler.save_result([{"data": {"CAMERA_CAPTURE": camera_capture_base64}}],
                                                                   device=device, data_type='attribute')
                         self.__result_handler.save_result([{"data": {"FRAME_COUNT": i}}], device=device,
@@ -494,7 +507,7 @@ class NDUCameraService(Thread):
                     def check_results(runner_unique_key_, results_, device_, results_for_preview_):
                         self.__result_handler.save_result(results_, device=device_,
                                                           runner_name=self.runners_configs_by_key[runner_unique_key_][
-                                                              "name"])
+                                                              "name"], data_type="telemetry")
                         if self.__preview_show:
                             results_for_preview_.extend(results_)
 
