@@ -30,5 +30,7 @@ RESULT_KEY_DATA = "data"
 RESULT_KEY_DEBUG = "debug"
 
 EXTRA_DATA_KEY_RESULTS = "results"
-LOCAL_RESULTS_DIR = "C:/temp/ndu"
-LOCAL_RESULTS_PATH = "C:/temp/ndu/local_results.txt"
+LOCAL_RESULTS_PATH = "local_results.txt"
+LOCAL_RESULT_LIMIT_BYTE = 131360
+SEND_FRAME='send_frame'
+CONFIGURATION_KEY = "conf"
