@@ -277,6 +277,19 @@ def denormalize_coordinates(image, coords):
         pnts.append((int(x * w), int(y * h)))
     return pnts
 
+def denormalize_coordinates_intersector(image, coords):
+    h, w = image.shape[:2]
+    pnts = []
+    for x, y in coords:
+        pnts.append([int(x * w), int(y * h)])
+    return pnts
+
+def normalize_coordinates_intersector(image, coords):
+    h, w = image.shape[:2]
+    pnts = []
+    for x, y in coords:
+        pnts.append([x / w, y / h])
+    return pnts
 
 def normalize_lines(image, lines):
     lines1 = []
